/*******************************************************************************
 *
 * gui.c - Creates and starts the GUI.
 *
 * Cheetah Web Browser
 * Copyright (C) 2001 Garett Spencley 
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 *
 *******************************************************************************/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "gui.h"
#include "error.h"
#include "menu.h"
#include "toolbar.h"
#include "display.h"
#include "statusbar.h"
#include "location.h"
#include "cheetah.h"

GtkWidget *window = NULL;

GtkWidget *init_window();
GtkWidget *create_menu();

/*
 * init_gui() - initialize the GUI
 */

int init_gui(int argc, char **argv)
{
	GtkWidget *box, *hbox;
	GtkWidget *action_box;
	GtkWidget *bookmark_box;

	gtk_init(&argc, &argv);

	window = init_window();
	if(!window) {
		error("Unable to create gtk+ window.");
		return -1;
	}	
	
	/* Vertical box for all our widgets */

	box = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(window), box);
	gtk_widget_show(box);

	/* Menu bar */
	init_menu(box);

	/* Horizontal handle box for location box and toolbar */
	
	action_box = gtk_handle_box_new();
	gtk_box_pack_start(GTK_BOX(box), action_box, FALSE, TRUE, 0);
	gtk_widget_show(action_box);

	hbox = gtk_hbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(action_box), hbox);
	gtk_widget_show(hbox);

	/* Toolbar */
	init_toolbar(hbox);

	/* Location box */
	init_location(hbox);


	bookmark_box = gtk_handle_box_new();
	gtk_box_pack_start(GTK_BOX(box), bookmark_box, FALSE, TRUE, 0);
	gtk_widget_show(bookmark_box);

	/* Display area */
	init_display_area(box);

	/* Status bar */
	init_statusbar(box);

	/* Show the window and enter main loop */

	gtk_widget_show(window);
	gtk_main();

	return 0;
}

/* 
 * init_window() - initialize the window
 */

GtkWidget *init_window()
{
	GtkWidget *result;

	/* Create the window */

	result = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	if(!result)
		return NULL;

	/* Set size and resizing policies */

	gtk_widget_set_usize(result, 800, 600);
	gtk_window_set_policy(GTK_WINDOW(result), TRUE, TRUE, FALSE);

	/* Connect all signals */

	gtk_signal_connect(GTK_OBJECT(result), "destroy",
		GTK_SIGNAL_FUNC(cheetah_close), NULL);

	/* Set title, border width etc. */

	gtk_window_set_title(GTK_WINDOW(result), CHEETAH_WINDOW_TITLE);
	gtk_container_set_border_width(GTK_CONTAINER(result), 2);

	return result;
}

/*
 * set_document_title() - set the document's title
 */

void set_document_title(char *title)
{
	char *string;
	int size;
	
	if(!title) 
		return;

	size = strlen(title) + strlen(CHEETAH_WINDOW_TITLE) + 5;

	string = (char *)malloc(sizeof(char) * size);
	if(!string) {
		error("Out of memory.");
		return;
	}

	snprintf(string, size-1, "%s - %s", title, CHEETAH_WINDOW_TITLE);	
	string[size-1] = 0;

	gtk_window_set_title(GTK_WINDOW(window), string);
	free(string);
}

/*
 * gui_quit() - close the gui
 */

void gui_quit()
{
	gtk_main_quit();
}
