/*******************************************************************************
 *
 * htmltokenizer.h - HTML parsing engine
 *
 * Hash functions for identifying html tags.
 *
 * Cheetah Web Browser
 * Copyright (C) 2001 Garett Spencley 
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 *
 *****************************************************************************/

#ifndef __HTML_TOKENIZER_H__
#define __HTML_TOKENIZER_H__

#include "htmlparser.h"

#define TOTAL_KEYWORDS 174
#define MIN_WORD_LENGTH 1
#define MAX_WORD_LENGTH 11
#define MIN_HASH_VALUE 1
#define MAX_HASH_VALUE 419

typedef enum {
	/* Opening tags */
	HTML_TAG_UNKOWN, HTML, HEAD, TITLE, BODY, CENTER, BOLD, UNDERLINE, 
	ITALIC,	PRE, SCRIPT, H1, H2, H3, H4, H5, H6, FONT, TABLE,
	TR, TD, PARA, BR, NOSCRIPT, CODE, FORM, INPUT, IMG, A, CITE, UL, OL,
	LI, ABBR, ACRONYM, ADDRESS, APPLET, AREA, BASE, BASEFONT, BDO, BIG, 
	BLOCKQUOTE, BUTTON, CAPTION, COL, COLGROUP, DD, DEL, DFN, DIRECTORY, 
	DIV, DL, DT, EM, FIELDSET, FRAME, FRAMESET, HR, IFRAME, INS, ISINDEX, 
	KBD, LABEL, LEGEND, LINK, MAP, MENU, META, NOFRAMES, OBJECT, OPTGROUP, 
	OPTION, PARAM, Q, S, SAMP, SELECT, SMALL, SPAN, STRONG, STYLE, SUB, 
	SUP, TBODY, TEXTAREA, TFOOT, TH, THEAD, TT, VAR, NOBR,

	/* Closing tags */
	EO_HTML, EO_HEAD, EO_TITLE, EO_BODY, EO_CENTER, EO_BOLD, EO_UNDERLINE, 
	EO_ITALIC, EO_PRE, EO_SCRIPT, EO_H1, EO_H2, EO_H3, EO_H4, EO_H5, EO_H6, 
	EO_FONT, EO_TABLE, EO_TR, EO_TD, EO_PARA, EO_BR, EO_NOSCRIPT, 
	EO_CODE, EO_FORM, EO_INPUT, EO_A, EO_CITE, EO_UL, EO_OL, EO_LI,
	EO_ABBR, EO_ACRONYM, EO_ADDRESS, EO_APPLET, EO_AREA, EO_BASE, EO_BASEFONT, 
	EO_BDO, EO_BIG, EO_BLOCKQUOTE, EO_BUTTON, EO_CAPTION, EO_DD, EO_DEL, EO_DFN,
   	EO_DIRECTORY, EO_DIV, EO_DL, EO_DT, EO_EM, EO_FIELDSET, EO_FRAME, 
	EO_FRAMESET, EO_IFRAME, EO_INS, EO_KBD, EO_LABEL, EO_LEGEND, EO_MAP, 
	EO_MENU, EO_NOFRAMES, EO_OBJECT, EO_OPTGROUP, EO_OPTION, EO_Q, EO_S, EO_SAMP, 
	EO_SELECT, EO_SMALL, EO_SPAN, EO_STRONG, EO_STYLE, EO_SUB, EO_SUP, EO_TBODY, 
	EO_TEXTAREA, EO_TFOOT, EO_TH, EO_THEAD, EO_TT, EO_VAR, EO_NOBR
} HTML_TAG_ID;

typedef struct {
	char *tag;
	HTML_TAG_ID id;
	int (*tag_func)(html_tag_args *args);
} html_token;

html_token *get_tag(char *);

#endif
