#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "uri.h"

uri_t *uri_new()
{
	uri_t *result;

	result = (uri_t *)malloc(sizeof(uri_t));
	if(!result)
		return NULL;

	return result;
}

void uri_free(uri_t *uri)
{
	if(!uri)
		return;

	free(uri->host);
	free(uri->doc);
}

protocol_t protocol_lookup(char *string)
{
	static const char *table[SUPPORTED_PROTOCOLS] = {
		"http://", "https://", "ftp://", "gopher://", "file:"
	};

	int i;

	for(i = 0; i < SUPPORTED_PROTOCOLS; i++) 
		if(strcasecmp(table[i], string) == 0)
			break;

	if(i == SUPPORTED_PROTOCOLS)
		return HTTP;

	return i;
}

uri_t *create_uri_struct(char *uri)
{
	uri_t *result;
	char proto[10], *p;
	char host[256], doc[256];

	result = uri_new();
	if(!result)
		return NULL;
	
	/* Extract protocol */

	if(strchr(uri, ':')) {
			
		p = proto;

		while(*uri) {

			*p++ = *uri;

			if(*uri == ':') {
				++uri;
				break;
			}

			++uri;
		} 
		*p = 0;

		if(strcasecmp(proto, "file:") != 0) {

			*p++ = *uri++; 
			*p++ = *uri++;

			*p = 0;
		}

		result->protocol = protocol_lookup(proto);

	} else 
		result->protocol = HTTP;

	/* If protocol is a file then make host the path
	 * and return */

	if(result->protocol == L_FILE) {
		result->host = strdup(uri);
		result->doc = strdup("");
		return result;
	}

	/* Extract host */


	p = host;

	while(*uri != '/' && *uri)
		*p++ = *uri++;

	*p = 0;

	result->host = strdup(host);

	/* Extract document (ie: /index.htm). If one does not 
	   exist use '/' */
	
	if(!*uri) 
		result->doc = strdup("/");
	else {
			
		p = doc;
		
		while(*uri) 
			*p++ = *uri++;

		*p = 0;

		result->doc = strdup(doc);
	}

	return result;
}
